=== modified file 'bzrlib/conflicts.py'
--- bzrlib/conflicts.py	2006-03-01 18:16:31 +0000
+++ bzrlib/conflicts.py	2006-03-09 22:54:29 +0000
@@ -29,8 +29,9 @@
 from bzrlib.commands import register_command
 from bzrlib.errors import BzrCommandError, NotConflicted
 from bzrlib.option import Option
+from bzrlib.osutils import rename
+from bzrlib.rio import Stanza
 from bzrlib.workingtree import CONFLICT_SUFFIXES, WorkingTree
-from bzrlib.osutils import rename
 
 class cmd_conflicts(bzrlib.commands.Command):
     """List files with conflicts.
@@ -121,3 +122,45 @@
             raise
     if not conflicted:
         raise NotConflicted(filename)
+
+
+def conflict_stanzas(conflicts):
+    for conflict in conflicts:
+        if conflict[0] in ('text conflict', 'path conflict', 
+                           'contents conflict'):
+            s = Stanza(type=conflict[0], path=conflict[2])
+            if conflict[1] is not None:
+                s.add('file_id', conflict[1]) 
+            yield s
+        else:
+            mydict = {'type': conflict[0], 'action': conflict[1], 
+                      'path': conflict[2]}
+            if conflict[3] is not None:
+                mydict['file_id'] = conflict[3]
+            if len(conflict) > 4:
+                mydict['conflict_path'] = conflict[4]
+                if conflict[5] is not None:
+                    mydict['conflict_file_id'] = conflict[5]
+            yield Stanza(**mydict)
+
+def stanza_conflicts(stanzas):
+    for stanza in stanzas:
+        try:
+            file_id = stanza['file_id']
+        except KeyError:
+            file_id = None
+        try:
+            conflict_file_id = stanza['conflict_file_id']
+        except KeyError:
+            conflict_file_id = None
+        if stanza.get('type') in ('text conflict', 'path conflict', 
+                                  'contents conflict'):
+            yield (stanza['type'], file_id, stanza['path'])
+        else:
+            my_list = [stanza['type'], stanza['action'],
+                       stanza['path'], file_id]
+            try:
+                my_list.extend((stanza['conflict_path'], conflict_file_id))
+            except KeyError:
+                pass
+            yield tuple(my_list) 

=== modified file 'bzrlib/tests/test_conflicts.py'
--- bzrlib/tests/test_conflicts.py	2006-01-24 04:44:33 +0000
+++ bzrlib/tests/test_conflicts.py	2006-03-09 22:54:29 +0000
@@ -17,14 +17,29 @@
 
 import os
 
-from bzrlib.tests import TestCaseWithTransport
+from bzrlib.tests import TestCaseWithTransport, TestCase
 from bzrlib.branch import Branch
-from bzrlib.conflicts import restore
+from bzrlib.conflicts import restore, stanza_conflicts, conflict_stanzas
 from bzrlib.errors import NotConflicted
 
+
 # TODO: Test commit with some added, and added-but-missing files
 # RBC 20060124 is that not tested in test_commit.py ?
 
+example_conflicts = [ 
+    ('contents conflict', 'ida', 'patha'),
+    ('text conflict', None, 'patha'),
+    ('path conflict', 'idb', 'pathb'),
+    ('duplicate id', 'Unversioned existing file', 'pathc', 'idc', 'pathc2', 
+     'idc'),
+    ('duplicate', 'Moved existing file to',  'pathdd.moved', 'idd', 'pathd', 
+     None),
+    ('parent loop', 'Cancelled move', 'pathe', None, 'path2e', 'id2e'),
+    ('unversioned parent', 'Versioned directory', 'pathf', 'idf'),
+    ('missing parent', 'Not deleting', 'pathg', 'idg'),
+]
+
+
 class TestConflicts(TestCaseWithTransport):
 
     def test_conflicts(self):
@@ -49,3 +64,23 @@
         assert not os.path.lexists('hello.sploo')
         self.assertRaises(NotConflicted, restore, 'hello')
         self.assertRaises(NotConflicted, restore, 'hello.sploo')
+
+
+class TestConflictStanzas(TestCase):
+    def test_stanza_roundtrip(self):
+        processed = list(stanza_conflicts(conflict_stanzas(example_conflicts)))
+        for o,p in zip(processed, example_conflicts):
+            self.assertEqual(o, p)
+
+    def test_stanzification(self):
+        for stanza in conflict_stanzas(example_conflicts):
+            try:
+                self.assertStartsWith(stanza['file_id'], 'id')
+            except KeyError:
+                pass
+            self.assertStartsWith(stanza['path'], 'path')
+            try:
+                self.assertStartsWith(stanza['conflict_file_id'], 'id')
+                self.assertStartsWith(stanza['conflict_file_path'], 'path')
+            except KeyError:
+                pass

